## Creating Instance based on inputs from based module

resource "aws_instance" "infra-instances" {

  ## AMI is fetched based on the deployment_region provided in base module
  ami              = lookup(var.ec2regionmap, var.deployment_region)
  key_name         = var.keyname
  user_data_base64 = var.userdata

  instance_type = var.instance_type

  ## Credit Specification is fetched based on Instance Type
  credit_specification {
    cpu_credits = lookup(var.credit_specification, var.instance_type)
  }

  network_interface {
    network_interface_id = aws_network_interface.external_interface.id
    device_index         = 0
  }

  network_interface {
    network_interface_id = aws_network_interface.internal_interface.id
    device_index         = 1
  }

  depends_on = [
    aws_eip_association.eip_association01,
    aws_eip_association.eip_association02
  ]

  ## Assign Name Tag to the machine
  tags = {
    Name = var.instance_name
  }
}