## Creating Variables for Core Instance module. You can add default values for each variable mentioned below.

variable "instance_type" {
  description = "Select one of the instance types"
  type        = string
  validation {
    condition     = contains(["t2.small", "t2.medium", "t2.large", "t3a.small", "t3a.medium", "t3a.large", "t3.small", "t3.medium", "t3.large", "m5.large", "m5n.large", "m5zn.large", "m5a.xlarge","m5.xlarge", "m5n.xlarge", "m5zn.xlarge"], var.instance_type)
    error_message = "Argument 'instance_type' must one of t2.small, t2.medium, t2.large, t3a.small, t3a.medium, t3a.large, t3.small, t3.medium, t3.large, m5.large, m5n.large, m5zn.large, m5a.xlarge,m5.xlarge, m5n.xlarge, m5zn.xlarge."
  }
}

variable "credit_specification" {
  description = "Credit Specification based on Instance Type"
  type        = map(any)
  default = {
    "t2.small"    = "unlimited",
    "t2.medium"   = "unlimited",
    "t2.large"    = "unlimited",
    "t3a.small"   = "unlimited",
    "t3a.medium"  = "unlimited",
    "t3a.large"   = "unlimited",
    "t3.small"    = "unlimited",
    "t3.medium"   = "unlimited",
    "t3.large"    = "unlimited",
    "m5.large"    = "standard",
    "m5n.large"   = "standard",
    "m5zn.large"  = "standard",
    "m5a.xlarge"  = "standard",
    "m5.xlarge"   = "standard",
    "m5n.xlarge"  = "standard",
    "m5zn.xlarge" = "standard"
  }
}

variable "instance_name" {
  description = "The name of the Instance"
  type        = string
}

variable "keyname" {
  description = "Key Pair Name"
}

variable "userdata" {
  description = "(Optional - Version 3.0 or more) Advanced Deployment: Paste here configUserData.json file content values."
  type        = string
}

variable "ec2regionmap" {
  description = "AMI mapping based on Region"
  type        = map(any)
  default = {
    af-south-1     = "ami-0d7218b063c22105f"
    ap-east-1      = "ami-0164a5c53458df62c"
    ap-northeast-1 = "ami-0d9af32d12c86279d"
    ap-northeast-2 = "ami-0ae3b31be120c6774"
    ap-south-1     = "ami-047a79addefd2a62b"
    ap-southeast-1 = "ami-05488c343bc8c0ba5"
    ap-southeast-2 = "ami-0136bb060714537c3"
    ca-central-1   = "ami-0e12051e4b0e97bfe"
    eu-central-1   = "ami-0a49d06cc9c2e7a71"
    eu-north-1     = "ami-0bcce64f6a0382de0"
    eu-south-1     = "ami-0ec6a6331a39e4f8b"
    eu-west-1      = "ami-01ee598e3e9cb5139"
    eu-west-2      = "ami-0f26e8c962483c01a"
    eu-west-3      = "ami-0c2903a2b77eee491"
    me-south-1     = "ami-0cdb17964d515289e"
    sa-east-1      = "ami-064e9a8c5c2ee2aa2"
    us-east-1      = "ami-01cd30e0531641a35"
    us-east-2      = "ami-0cce08acff38a46fb"
    us-west-1      = "ami-0ea81c9d8129ae25d"
    us-west-2      = "ami-0914afc1bdefe9f0d"
    us-gov-east-1  = "ami-033d4216334e6f450"
    us-gov-west-1  = "ami-0c5409183c6a22fff"
  }
}

variable "deployment_region" {
  description = "Region to deploy the infrastructure in"
}

variable "external_subnet_id" {
  description = "Select an External Subnet (WARNING !! must be on the same availability zone as Internal Subnet)"
}

variable "internal_subnet_id" {
  description = "Select an Internal Subnet (WARNING !! must be on the same availability zone as Internal Subnet)"
}

variable "stack_name" {
  description = "Stack name for deployment"
}

variable "vpc_id" {
  description = "VPC ID used for deployment"
}